### rjj (read-joint-jet)
rjj is a simple cmd-based data cleaning tool; rjj comes from the slogan "are you Ready? Joint me or split me; easy Job!"
#### install it via (pip/pip3):
```
pip install rjj
```
#### update cgg
```
pip install rjj --upgrade
```
#### check current version
```
rjj -v
```
#### read user manual
```
rjj -h
```
### jointer and spliter
joint or split your csv file(s) with a simple command below
#### jointer
csv jointer
```
rjj j
```
#### spliter
csv spliter
```
rjj s
```
